---

<div align="center">

### PCILeech Firmware Generator – 

[![CI](https://github.com/ramsey/PCILeechFWGenerator/actions/workflows/ci.yml/badge.svg)](https://github.com/ramsey/PCILeechFWGenerator/actions)&nbsp;
[![Latest Release](https://img.shields.io/github/v/release/ramsey/PCILeechFWGenerator?label=latest)](https://github.com/ramsey/PCILeechFWGenerator/releases)&nbsp;
[![License MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/ramsey/PCILeechFWGenerator/blob/main/LICENSE)

| **Docs** | **Issues** | **Discussions** | **Changelog** |
|:---|:---|:---|:---|
| [Documentation](/) • [Architecture](template-architecture) • [Devices](supported-devices) | [Bug Tracker](https://github.com/ramsey/PCILeechFWGenerator/issues) | [Q & A](https://github.com/ramsey/PCILeechFWGenerator/discussions) | [Release Notes](https://github.com/ramsey/PCILeechFWGenerator/releases) |

<sub>
© 2024-2025 Ramsey McGrath & contributors.  
Run it, mod it, break it—just don’t complain when the magic smoke escapes.  
Got improvements? Open a PR. Reading this in 2030? Prove the project’s still alive and do the same.
</sub>

</div>
